@@ -318,7 +318,7 @@ def add_reference_cert_id(target_diff_list: list, source_device: SourceDevice):
                            r'rsakeypair TP-self-signed-##########',
                            r'crypto pki certificate chain TP-self-signed-##########']
 
-    if match_token_id in [None, False]:
+    if not match_token_id:
         print('No matches were found for the Token ID.')
     elif len(match_token_id) > 1:
         print("Multiple strings were matched while looking for the Token ID.\n" +
